@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: esqueleto
 version: 2.4.3
-id: esqueleto-2.4.3-d3f7fac89495c2a2de6f99ff3c145caa
-key: esque_J4UKviL5vns2XKFt7M40ps
+id: esqueleto-2.4.3-1811f340ff0dc33d46d950dbd44a06e4
+key: esque_4jVO72Vt0R6EpTBvplRbUc
 license: BSD3
 copyright: (c) 2012-2015 Felipe Almeida Lessa
 maintainer: felipe.lessa@gmail.com
@@ -52,16 +52,16 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/esqueleto-2.4.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/esqueleto-2.4.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/esqueleto-2.4.3
-hs-libraries: HSesqueleto-2.4.3-J4UKviL5vns2XKFt7M40ps
+hs-libraries: HSesqueleto-2.4.3-4jVO72Vt0R6EpTBvplRbUc
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
+    blaze-html-0.8.1.1-196db2ddcb827bc04473411dd00dd5eb
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
-    monad-logger-0.3.18-e41795701bd26d2e948311dc59f0bce2
-    persistent-2.2.4.1-515160ea71a89b76b70a56c63b058aa3
-    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
-    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
+    conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
+    monad-logger-0.3.18-8d0d3ee0b0c9e28288fbc3f8ad4970cb
+    persistent-2.2.4.1-b198a8037ee23ace95ee55f6faca82c3
+    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
+    tagged-0.8.4-af2e23230031c45949e0062e776a8f1f
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
